@@ -4,23 +4,22 @@
 #'
 #' @param file The path to the a .pdf, .txt, .html, .rtf, .docx, or .doc file.
 #' @param skip The number of lines to skip.
-#' @param remove.empty logical.  If \code{TRUE} empty elements in the vector are
+#' @param remove.empty logical.  If `TRUE` empty elements in the vector are
 #' removed.
-#' @param trim logical.  If \code{TRUE} the leading/training white space is
+#' @param trim logical.  If `TRUE` the leading/training white space is
 #' removed.
-#' @param combine logical.  If \code{TRUE} the vector is concatenated into a
-#' single string via \code{\link[textshape]{combine}}.
-#' @param format For .doc files only.  Logical.  If \code{TRUE} the output will
+#' @param combine logical.  If `TRUE` the vector is concatenated into a
+#' single string via [textshape::combine()].
+#' @param format For .doc files only.  Logical.  If `TRUE` the output will
 #' keep doc formatting (e.g., bold, italics, underlined).  This corresponds to
-#' the \code{-f} flag in antiword.
-#' @param ocr logical.  If \code{TRUE} .pdf documents with a non-text pull using
-#' \code{\link[pdftools]{pdf_text}} will be re-run using OCR via the
-#' \code{\link[tesseract]{ocr}} function.  This will create temporary .png
+#' the \code{-f} flag in **antiword**.
+#' @param ocr logical.  If `TRUE` .pdf documents with a non-text pull using
+#' [pdftools::pdf_text()][pdftools::pdftools] will be re-run using OCR via the
+#' [tesseract::ocr()] function.  This will create temporary .png
 #' files and will require a much larger compute time.
-#' @param \ldots Other arguments passed to \code{\link[textreadr]{read_pdf}},
-#' \code{\link[textreadr]{read_html}}, \code{\link[textreadr]{read_docx}},
-#' \code{\link[textreadr]{read_doc}}, or \code{\link[base]{readLines}}.
-#' @return Returns a \code{\link[base]{list}} of string \code{\link[base]{vector}}s.
+#' @param ... Other arguments passed to [read_pdf()],
+#' [read_html()], [read_docx()], [read_doc()], or [base::readLines()].
+#' @return Returns a [base::list()] of string [base::vector()]s.
 #' @export
 #' @examples
 #' ## .pdf
@@ -45,7 +44,11 @@
 #' ## .txt
 #' txt_doc <- system.file('docs/textreadr_creed.txt', package = "textreadr")
 #' read_document(txt_doc)
-#'
+#' 
+#' ## .pptx 
+#' pptx_doc <- system.file('docs/Hello_World.pptx', package = "textreadr")
+#' read_document(pptx_doc)
+#' 
 #' ## .rtf
 #' \dontrun{
 #' rtf_doc <- download(
@@ -53,7 +56,7 @@
 #' )
 #' read_document(rtf_doc)
 #' }
-#'
+#' 
 #' \dontrun{
 #' ## URLs
 #' read_document('http://www.talkstats.com/index.php')
@@ -61,10 +64,12 @@
 read_document <- function(file, skip = 0, remove.empty = TRUE, trim = TRUE,
     combine = FALSE, format = FALSE, ocr = TRUE, ...){
 
-    if (grepl('^([fh]ttp)', file)){
+    filetype <- tools::file_ext(file)
+        
+    if (!filetype %in% c('pdf', 'docx', 'doc',  'rtf', 'html', 'txt', 'pptx') && grepl('^([fh]ttp)', file)){
         filetype <- 'html'
     } else {
-        filetype <- tools::file_ext(file)
+     
         filetype <- ifelse(filetype %in% c('php', 'htm'), 'html', filetype)
     }
 
@@ -74,7 +79,9 @@ read_document <- function(file, skip = 0, remove.empty = TRUE, trim = TRUE,
         doc = {function(x, ...) {read_doc(x, remove.empty = FALSE, trim = FALSE, format=format, ...)}},
         rtf = {function(x, ...) {read_rtf(x, remove.empty = FALSE, trim = FALSE, ...)}},
         html = {function(x, ...) {read_html(x, remove.empty = FALSE, trim = FALSE, ...)}},
+        xml = {function(x, ...) {read_xml(x, remove.empty = FALSE, trim = FALSE, ...)}},        
         txt = {function(x, ...) {suppressWarnings(readLines(x, ...))}},
+        pptx = {function(x, ...) {read_pptx(x, remove.empty = FALSE, trim = FALSE, ...)[["text"]]}},
         {function(x, ...) {suppressWarnings(readLines(x, ...))}}
     )
 
@@ -85,7 +92,8 @@ read_document <- function(file, skip = 0, remove.empty = TRUE, trim = TRUE,
     if (isTRUE(remove.empty)) out <- out[!grepl("^\\s*$", out)]
     if (skip > 0) out <- out[-seq(skip)]
     if (isTRUE(trim)) out <- trimws(out)
-
+    if (length(out) == 0) out <- ''
+    
 
     if (isTRUE(combine)) out <- textshape::combine(out)
     out
