@@ -4,11 +4,11 @@
 #'
 #' @param file The path to the .docx file.
 #' @param skip The number of lines to skip.
-#' @param remove.empty logical.  If \code{TRUE} empty elements in the vector are
+#' @param remove.empty logical.  If `TRUE` empty elements in the vector are
 #' removed.
-#' @param trim logical.  If \code{TRUE} the leading/training white space is
+#' @param trim logical.  If `TRUE` the leading/training white space is
 #' removed.
-#' @param \dots ignored.
+#' @param ... ignored.
 #' @return Returns a character vector.
 #' @keywords docx
 #' @export
@@ -21,6 +21,13 @@
 #' }
 read_docx <- function (file, skip = 0, remove.empty = TRUE, trim = TRUE, ...) {
 
+    filetype <- tools::file_ext(file)
+    if (filetype %in% c('docx') && grepl('^([fh]ttp)', file)){
+
+        file <- download(file)
+
+    }   
+
     ## create temp dir
     tmp <- tempfile()
     if (!dir.create(tmp)) stop("Temporary directory could not be established.")
@@ -35,15 +42,27 @@ read_docx <- function (file, skip = 0, remove.empty = TRUE, trim = TRUE, ...) {
     ## read in the unzipped docx
     doc <- xml2::read_xml(xmlfile)
 
+    ### extract the content
+    # children <- lapply(xml2::xml_find_all(doc, '//w:p'), xml2::xml_children)
+    # pvalues <- unlist(lapply(children, function(x) {
+    #     paste(xml2::xml_text(xml2::xml_find_all(x, 'w:t')), collapse = ' ')
+    # }))
+    
     ## extract the content
-    nodeSet <- xml2::xml_find_all(doc, "//w:p")
-    pvalues <- xml2::xml_text(nodeSet)
+    rm_na <- function(x) x[!is.na(x)]
+
+    pvalues <- unlist(lapply(lapply(xml2::xml_find_all(doc, '//w:p'), xml2::xml_children), function(x) {
+
+        paste(rm_na(unlist(xml2::xml_text(xml2::xml_find_all(x, './/w:t')))), collapse = ' ')
+
+    }))    
 
     ## formatting
     if (isTRUE(remove.empty)) pvalues <- pvalues[!grepl("^\\s*$", pvalues)]
     if (skip > 0) pvalues <- pvalues[-seq(skip)]
     if (isTRUE(trim)) pvalues <- trimws(pvalues)
-
+    if (length(pvalues) == 0) pvalues <- ''
+    
     pvalues
 
 }
